#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Personal setup
"""


CRUNCHER = 'XX'
PATH_TO_DATASHELF = r'/PPP/PPP'
DB_READ_ONLY = True
DEBUG = False